@@ -85,7 +85,7 @@ static GdkDragAction xfdesktop_volume_icon_get_allowed_drag_actions(XfdesktopIco
 static GdkDragAction xfdesktop_volume_icon_get_allowed_drop_actions(XfdesktopIcon *icon,
                                                                     GdkDragAction *suggested_action);
 static gboolean xfdesktop_volume_icon_do_drop_dest(XfdesktopIcon *icon,
-                                                   XfdesktopIcon *src_icon,
+                                                   GList *src_icons,
                                                    GdkDragAction action);
 static gboolean xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
                                                             GtkWidget *menu);
@@ -96,8 +96,8 @@ static GFile *xfdesktop_volume_icon_peek_file(XfdesktopFileIcon *icon);
 static void xfdesktop_volume_icon_update_file_info(XfdesktopFileIcon *icon,
                                                    GFileInfo *info);
 static gboolean xfdesktop_volume_icon_activated(XfdesktopIcon *icon);
-static gboolean volume_icon_changed_timeout(XfdesktopVolumeIcon *icon);
-static void xfdesktop_volume_icon_changed(GVolume *volume, 
+static gboolean volume_icon_changed_timeout(gpointer user_data);
+static void xfdesktop_volume_icon_changed(GVolume *volume,
                                           XfdesktopVolumeIcon *volume_icon);
 
 #ifdef HAVE_THUNARX
@@ -107,10 +107,11 @@ G_DEFINE_TYPE_EXTENDED(XfdesktopVolumeIcon, xfdesktop_volume_icon,
                        XFDESKTOP_TYPE_FILE_ICON, 0,
                        G_IMPLEMENT_INTERFACE(THUNARX_TYPE_FILE_INFO,
                                              xfdesktop_volume_icon_tfi_init)
+                       G_ADD_PRIVATE(XfdesktopVolumeIcon)
                        )
 #else
-G_DEFINE_TYPE(XfdesktopVolumeIcon, xfdesktop_volume_icon,
-              XFDESKTOP_TYPE_FILE_ICON)
+G_DEFINE_TYPE_WITH_PRIVATE(XfdesktopVolumeIcon, xfdesktop_volume_icon,
+                           XFDESKTOP_TYPE_FILE_ICON)
 #endif
 
 
@@ -127,11 +128,9 @@ xfdesktop_volume_icon_class_init(XfdesktopVolumeIconClass *klass)
     XfdesktopFileIconClass *file_icon_class = (XfdesktopFileIconClass *)klass;
 
     xfdesktop_volume_icon_activated_quark = g_quark_from_static_string("xfdesktop-volume-icon-activated");
-    
-    g_type_class_add_private(klass, sizeof(XfdesktopVolumeIconClass));
-    
+
     gobject_class->finalize = xfdesktop_volume_icon_finalize;
-    
+
     icon_class->peek_pixbuf = xfdesktop_volume_icon_peek_pixbuf;
     icon_class->peek_label = xfdesktop_volume_icon_peek_label;
     icon_class->get_identifier = xfdesktop_volume_icon_get_identifier;
@@ -142,20 +141,17 @@ xfdesktop_volume_icon_class_init(XfdesktopVolumeIconClass *klass)
     icon_class->do_drop_dest = xfdesktop_volume_icon_do_drop_dest;
     icon_class->populate_context_menu = xfdesktop_volume_icon_populate_context_menu;
     icon_class->activated = xfdesktop_volume_icon_activated;
-    
+
     file_icon_class->peek_file_info = xfdesktop_volume_icon_peek_file_info;
     file_icon_class->peek_filesystem_info = xfdesktop_volume_icon_peek_filesystem_info;
     file_icon_class->peek_file = xfdesktop_volume_icon_peek_file;
     file_icon_class->update_file_info = xfdesktop_volume_icon_update_file_info;
-    file_icon_class->can_rename_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
-    file_icon_class->can_delete_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
 }
 
 static void
 xfdesktop_volume_icon_init(XfdesktopVolumeIcon *icon)
 {
-    icon->priv = G_TYPE_INSTANCE_GET_PRIVATE(icon, XFDESKTOP_TYPE_VOLUME_ICON,
-                                             XfdesktopVolumeIconPrivate);
+    icon->priv = xfdesktop_volume_icon_get_instance_private(icon);
 }
 
 static void
@@ -167,11 +163,11 @@ xfdesktop_volume_icon_finalize(GObject *obj)
     /* remove pending change timeouts */
     if(icon->priv->changed_timeout_id > 0)
         g_source_remove(icon->priv->changed_timeout_id);
-    
+
     g_signal_handlers_disconnect_by_func(G_OBJECT(itheme),
                                          G_CALLBACK(xfdesktop_icon_invalidate_pixbuf),
                                          icon);
-    
+
     if(icon->priv->label) {
         g_free(icon->priv->label);
         icon->priv->label = NULL;
@@ -191,7 +187,7 @@ xfdesktop_volume_icon_finalize(GObject *obj)
 
     if(icon->priv->tooltip)
         g_free(icon->priv->tooltip);
-    
+
     G_OBJECT_CLASS(xfdesktop_volume_icon_parent_class)->finalize(obj);
 }
 
@@ -270,7 +266,7 @@ xfdesktop_volume_icon_peek_pixbuf(XfdesktopIcon *icon,
     gint opacity = 100;
     GIcon *gicon = NULL;
     GdkPixbuf *pix = NULL;
-    
+
     g_return_val_if_fail(XFDESKTOP_IS_VOLUME_ICON(icon), NULL);
 
     if(!xfdesktop_file_icon_has_gicon(XFDESKTOP_FILE_ICON(icon)))
@@ -312,7 +308,7 @@ xfdesktop_volume_icon_peek_label(XfdesktopIcon *icon)
     XfdesktopVolumeIcon *volume_icon = XFDESKTOP_VOLUME_ICON(icon);
 
     g_return_val_if_fail(XFDESKTOP_IS_VOLUME_ICON(icon), NULL);
-    
+
     if(!volume_icon->priv->label) {
             volume_icon->priv->label = g_volume_get_name(volume_icon->priv->volume);
     }
@@ -342,10 +338,10 @@ xfdesktop_volume_icon_get_allowed_drag_actions(XfdesktopIcon *icon)
      * the mount point, but copying and linking should be OK.  when not mounted,
      * we should just disallow everything, since, even if its ThunarVfsInfo
      * is valid, we can't guarantee it won't change after mounting. */
-    
+
     /* FIXME: should i allow all actions if not mounted as well, and try to
      * mount and resolve on drop? */
-    
+
     if(xfdesktop_volume_icon_is_mounted(icon)) {
         GFileInfo *info = xfdesktop_file_icon_peek_file_info(XFDESKTOP_FILE_ICON(icon));
         if(info) {
@@ -355,7 +351,7 @@ xfdesktop_volume_icon_get_allowed_drag_actions(XfdesktopIcon *icon)
                 return GDK_ACTION_LINK;
         }
     }
-    
+
     return 0;
 }
 
@@ -365,7 +361,7 @@ xfdesktop_volume_icon_get_allowed_drop_actions(XfdesktopIcon *icon,
 {
     /* if not mounted, it doesn't really make sense to allow any operations
      * here.  if mounted, we should allow everything if it's writable. */
-    
+
     /* FIXME: should i allow all actions if not mounted as well, and try to
      * mount and resolve on drop? */
 
@@ -382,77 +378,37 @@ xfdesktop_volume_icon_get_allowed_drop_actions(XfdesktopIcon *icon,
 
     if(suggested_action)
         *suggested_action = 0;
-    
+
     return 0;
 }
 
 static gboolean
 xfdesktop_volume_icon_do_drop_dest(XfdesktopIcon *icon,
-                                 XfdesktopIcon *src_icon,
-                                 GdkDragAction action)
+                                   GList *src_icons,
+                                   GdkDragAction action)
 {
     XfdesktopVolumeIcon *volume_icon = XFDESKTOP_VOLUME_ICON(icon);
-    XfdesktopFileIcon *src_file_icon = XFDESKTOP_FILE_ICON(src_icon);
-    GFileInfo *src_info;
-    GFile *src_file, *parent, *dest_file = NULL;
     gboolean result = FALSE;
-    gchar *name;
-    
+    GList *src_files = NULL;
+    GList *dest_files = NULL;
+
     TRACE("entering");
-    
-    g_return_val_if_fail(volume_icon && src_file_icon, FALSE);
+
+    g_return_val_if_fail(volume_icon != NULL && src_icons != NULL, FALSE);
     g_return_val_if_fail(xfdesktop_volume_icon_get_allowed_drop_actions(icon, NULL),
                          FALSE);
-    
-    src_file = xfdesktop_file_icon_peek_file(src_file_icon);
 
-    src_info = xfdesktop_file_icon_peek_file_info(src_file_icon);
-    if(!src_info)
-        return FALSE;
-
-    if(!volume_icon->priv->file_info)
-        return FALSE;
-   
-    parent = g_file_get_parent(src_file);
-    if(!parent)
-        return FALSE;
-    g_object_unref(parent);
-        
-    name = g_file_get_basename(src_file);
-    if(!name)
-        return FALSE;
-    
-    switch(action) {
-        case GDK_ACTION_MOVE:
-            XF_DEBUG("doing move");
-            dest_file = g_object_ref(volume_icon->priv->file);
-            break;
-        
-        case GDK_ACTION_COPY:
-            XF_DEBUG("doing copy");
-            dest_file = g_file_get_child(volume_icon->priv->file, name);
-            break;
-        
-        case GDK_ACTION_LINK:
-            XF_DEBUG("doing link");
-            dest_file = g_object_ref(volume_icon->priv->file);
-            break;
-        
-        default:
-            g_warning("Unsupported drag action: %d", action);
-    }
-
-    if(dest_file) {
-        xfdesktop_file_utils_transfer_file(action, src_file, dest_file,
-                                           volume_icon->priv->gscreen);
-    
-        g_object_unref(dest_file);
+    xfdesktop_file_utils_build_transfer_file_lists(action, src_icons, XFDESKTOP_FILE_ICON(icon), &src_files, &dest_files);
 
+    if (src_files != NULL && dest_files != NULL) {
+        xfdesktop_file_utils_transfer_files(action, src_files, dest_files,
+                                            volume_icon->priv->gscreen);
         result = TRUE;
     }
 
-    g_free(name);
-        
+    g_list_free_full(dest_files, g_object_unref);
+    g_list_free(src_files);
+
     return result;
 }
 
@@ -462,12 +418,13 @@ xfdesktop_volume_icon_peek_tooltip(XfdesktopIcon *icon)
     XfdesktopVolumeIcon *volume_icon = XFDESKTOP_VOLUME_ICON(icon);
     GFileInfo *fs_info = xfdesktop_file_icon_peek_filesystem_info(XFDESKTOP_FILE_ICON(icon));
     GFile *file = xfdesktop_file_icon_peek_file(XFDESKTOP_FILE_ICON(icon));
-    
+
     if(!volume_icon->priv->tooltip) {
-        guint64 size, free_space;
         gchar *mount_point = NULL, *size_string = NULL, *free_space_string = NULL;
 
         if(file && fs_info) {
+            guint64 size, free_space;
+
             mount_point = g_file_get_parse_name(file);
 
             size = g_file_info_get_attribute_uint64(fs_info,
@@ -477,17 +434,23 @@ xfdesktop_volume_icon_peek_tooltip(XfdesktopIcon *icon)
 
             size_string = g_format_size(size);
             free_space_string = g_format_size(free_space);
-
-            volume_icon->priv->tooltip =
-                g_strdup_printf(_("Removable Volume\nMounted in \"%s\"\n%s left (%s total)"),
-                                mount_point, free_space_string, size_string);
-    
-            g_free(free_space_string);
-            g_free(size_string);
-            g_free(mount_point);
         } else {
-            volume_icon->priv->tooltip = g_strdup(_("Removable Volume\nNot mounted yet"));
+            mount_point = g_strdup(_("(not mounted)"));
+            size_string = g_strdup(_("(unknown)"));
+            free_space_string = g_strdup(_("(unknown)"));
         }
+
+        volume_icon->priv->tooltip =
+            g_strdup_printf(_("Name: %s\nType: %s\nMounted at: %s\nSize: %s\nFree Space: %s"),
+                            volume_icon->priv->label,
+                            _("Removable Volume"),
+                            mount_point,
+                            size_string,
+                            free_space_string);
+
+        g_free(free_space_string);
+        g_free(size_string);
+        g_free(mount_point);
     }
 
     return volume_icon->priv->tooltip;
@@ -504,7 +467,7 @@ xfdesktop_volume_icon_eject_finish(GObject *object,
     GVolume *volume = G_VOLUME(object);
     GError *error = NULL;
     gboolean eject_successful;
-      
+
     g_return_if_fail(G_IS_VOLUME(object));
     g_return_if_fail(G_IS_ASYNC_RESULT(result));
     g_return_if_fail(XFDESKTOP_IS_VOLUME_ICON(icon));
@@ -515,12 +478,12 @@ xfdesktop_volume_icon_eject_finish(GObject *object,
         /* ignore GIO errors handled internally */
         if(error->domain != G_IO_ERROR || error->code != G_IO_ERROR_FAILED_HANDLED) {
             gchar *volume_name = g_volume_get_name(volume);
-            gchar *primary = g_markup_printf_escaped(_("Failed to eject \"%s\""), 
+            gchar *primary = g_markup_printf_escaped(_("Failed to eject \"%s\""),
                                                      volume_name);
 
             /* display an error dialog to inform the user */
             xfce_message_dialog(toplevel ? GTK_WINDOW(toplevel) : NULL,
-                                _("Eject Failed"), "dialog-error", 
+                                _("Eject Failed"), "dialog-error",
                                 primary, error->message,
                                 XFCE_BUTTON_TYPE_MIXED, "window-close", _("_Close"), GTK_RESPONSE_ACCEPT,
                                 NULL);
@@ -550,7 +513,7 @@ xfdesktop_volume_icon_unmount_finish(GObject *object,
     GMount *mount = G_MOUNT(object);
     GError *error = NULL;
     gboolean unmount_successful;
-      
+
     g_return_if_fail(G_IS_MOUNT(object));
     g_return_if_fail(G_IS_ASYNC_RESULT(result));
     g_return_if_fail(XFDESKTOP_IS_VOLUME_ICON(icon));
@@ -561,12 +524,12 @@ xfdesktop_volume_icon_unmount_finish(GObject *object,
         /* ignore GIO errors handled internally */
         if(error->domain != G_IO_ERROR || error->code != G_IO_ERROR_FAILED_HANDLED) {
             gchar *mount_name = g_mount_get_name(mount);
-            gchar *primary = g_markup_printf_escaped(_("Failed to eject \"%s\""), 
+            gchar *primary = g_markup_printf_escaped(_("Failed to eject \"%s\""),
                                                      mount_name);
 
             /* display an error dialog to inform the user */
             xfce_message_dialog(toplevel ? GTK_WINDOW(toplevel) : NULL,
-                                _("Eject Failed"), "dialog-error", 
+                                _("Eject Failed"), "dialog-error",
                                 primary, error->message,
                                 XFCE_BUTTON_TYPE_MIXED, "window-close", _("_Close"), GTK_RESPONSE_ACCEPT,
                                 NULL);
@@ -602,14 +565,14 @@ xfdesktop_volume_icon_mount_finish(GObject *object,
             gchar *primary = g_markup_printf_escaped(_("Failed to mount \"%s\""),
                                                      volume_name);
             xfce_message_dialog(toplevel ? GTK_WINDOW(toplevel) : NULL,
-                                _("Mount Failed"), "dialog-error", 
+                                _("Mount Failed"), "dialog-error",
                                 primary, error->message,
                                 XFCE_BUTTON_TYPE_MIXED, "window-close", _("_Close"), GTK_RESPONSE_ACCEPT,
                                 NULL);
             g_free(primary);
             g_free(volume_name);
         }
-        
+
         g_clear_error(&error);
     } else {
         GMount *mount = g_volume_get_mount(volume);
@@ -634,7 +597,7 @@ xfdesktop_volume_icon_mount_finish(GObject *object,
 
             xfdesktop_file_icon_update_file_info(XFDESKTOP_FILE_ICON(icon), info);
 
-            activated = GPOINTER_TO_UINT(g_object_get_qdata(G_OBJECT(icon), 
+            activated = GPOINTER_TO_UINT(g_object_get_qdata(G_OBJECT(icon),
                                                             xfdesktop_volume_icon_activated_quark));
             if(activated) {
                 XfdesktopIcon *icon_p = XFDESKTOP_ICON(icon);
@@ -648,7 +611,7 @@ xfdesktop_volume_icon_mount_finish(GObject *object,
 
             xfdesktop_file_icon_update_file_info(XFDESKTOP_FILE_ICON(icon), NULL);
         }
-            
+
         if(file)
             g_object_unref(file);
 
@@ -766,12 +729,15 @@ static void
 xfdesktop_volume_icon_menu_properties(GtkWidget *widget,
                                       gpointer user_data)
 {
-    XfdesktopFileIcon *icon = XFDESKTOP_FILE_ICON(user_data);        
-    GFile *file;
-    
-    file = xfdesktop_file_icon_peek_file(icon);
-    xfdesktop_file_utils_show_properties_dialog(file, 
-                                                XFDESKTOP_VOLUME_ICON(icon)->priv->gscreen, 
+    XfdesktopFileIcon *icon = XFDESKTOP_FILE_ICON(user_data);
+    GFile *file = xfdesktop_file_icon_peek_file(icon);
+    GList file_l = {
+        .data = file,
+        .next = NULL,
+    };
+
+    xfdesktop_file_utils_show_properties_dialog(&file_l,
+                                                XFDESKTOP_VOLUME_ICON(icon)->priv->gscreen,
                                                 NULL);
 }
 
@@ -809,22 +775,48 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
 
     icon_name = "document-open";
 
-    img = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_MENU);
+    img = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_MENU);
     mi = xfdesktop_menu_create_menu_item_with_mnemonic(_("_Open"), img);
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
     g_signal_connect_swapped(G_OBJECT(mi), "activate",
                              G_CALLBACK(xfdesktop_icon_activated), icon);
-    
+
     mi = gtk_separator_menu_item_new();
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
-    
+
     mount = g_volume_get_mount(volume);
 
-    if(mount && g_volume_can_eject(volume)) {
+    if (g_volume_can_eject(volume)) {
+        GDrive              *drive;
+        GDriveStartStopType  start_stop_type = G_DRIVE_START_STOP_TYPE_UNKNOWN;
+
+        drive = g_volume_get_drive (volume);
+        if (drive != NULL)
+          {
+            start_stop_type = g_drive_get_start_stop_type (drive);
+            g_object_unref (drive);
+          }
+
+        switch (start_stop_type)
+          {
+          case G_DRIVE_START_STOP_TYPE_SHUTDOWN:
+            icon_label = _("_Safely Remove Volume");
+            break;
+          case G_DRIVE_START_STOP_TYPE_NETWORK:
+            icon_label = _("_Disconnect Volume");
+            break;
+          case G_DRIVE_START_STOP_TYPE_MULTIDISK:
+            icon_label = _("_Stop the Multi-Disk Drive");
+            break;
+          case G_DRIVE_START_STOP_TYPE_PASSWORD:
+            icon_label = _("_Lock Volume");
+            break;
+          default:
+            icon_label = _("E_ject Volume");
+          }
         icon_name = "media-eject";
-        icon_label = _("E_ject Volume");
         xfdesktop_volume_icon_add_context_menu_option(icon, icon_name, icon_label,
                         menu, G_CALLBACK(xfdesktop_volume_icon_menu_eject));
     }
@@ -860,7 +852,7 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
         xfdesktop_volume_icon_add_context_menu_option(icon, icon_name, icon_label,
                     menu, G_CALLBACK(xfdesktop_volume_icon_menu_properties));
     }
-    
+
     return TRUE;
 }
 
@@ -928,13 +920,13 @@ xfdesktop_volume_icon_activated(XfdesktopIcon *icon_p)
     XfdesktopVolumeIcon *icon = XFDESKTOP_VOLUME_ICON(icon_p);
     GVolume *volume = xfdesktop_volume_icon_peek_volume(icon);
     GMount *mount;
-    
+
     TRACE("entering");
 
     mount = g_volume_get_mount(volume);
-    
+
     if(!mount) {
-        /* set the activated flag so we can chain the event up to the 
+        /* set the activated flag so we can chain the event up to the
          * parent class in the mount finish callback */
         g_object_set_qdata(G_OBJECT(icon), xfdesktop_volume_icon_activated_quark,
                            GUINT_TO_POINTER(TRUE));
@@ -953,8 +945,9 @@ xfdesktop_volume_icon_activated(XfdesktopIcon *icon_p)
 }
 
 static gboolean
-volume_icon_changed_timeout(XfdesktopVolumeIcon *volume_icon)
+volume_icon_changed_timeout(gpointer user_data)
 {
+    XfdesktopVolumeIcon *volume_icon = user_data;
     GMount *mount;
     gboolean mounted_before = FALSE;
     gboolean mounted_after = FALSE;
@@ -986,12 +979,12 @@ volume_icon_changed_timeout(XfdesktopVolumeIcon *volume_icon)
     if(mount) {
         /* load mount point information */
         volume_icon->priv->file = g_mount_get_root(mount);
-        volume_icon->priv->file_info = 
-            g_file_query_info(volume_icon->priv->file, 
+        volume_icon->priv->file_info =
+            g_file_query_info(volume_icon->priv->file,
                               XFDESKTOP_FILE_INFO_NAMESPACE,
                               G_FILE_QUERY_INFO_NONE,
                               NULL, NULL);
-        volume_icon->priv->filesystem_info = 
+        volume_icon->priv->filesystem_info =
             g_file_query_filesystem_info(volume_icon->priv->file,
                                          XFDESKTOP_FILESYSTEM_INFO_NAMESPACE,
                                          NULL, NULL);
@@ -1044,13 +1037,13 @@ xfdesktop_volume_icon_changed(GVolume *volume,
     XF_DEBUG("VOLUME CHANGED");
 
     /**
-     * NOTE: We use a timeout here to check if the volume is 
+     * NOTE: We use a timeout here to check if the volume is
      * now mounted (or has been unmounted). This timeout seems
      * to be needed because when the "changed" signal is emitted,
      * the GMount is always NULL. In a 500ms timeout we check
      * at most 5 times for a valid mount until we give up. This
      * hopefully is a suitable workaround for most machines and
-     * drives. 
+     * drives.
      */
 
     /* abort an existing timeout, we may have to run it a few times
@@ -1063,8 +1056,8 @@ xfdesktop_volume_icon_changed(GVolume *volume,
     /* reset timeout information and start a timeout */
     volume_icon->priv->changed_timeout_count = 0;
     volume_icon->priv->changed_timeout_id =
-        g_timeout_add_full(G_PRIORITY_LOW, 500, 
-                           (GSourceFunc) volume_icon_changed_timeout, 
+        g_timeout_add_full(G_PRIORITY_LOW, 500,
+                           volume_icon_changed_timeout,
                            g_object_ref(volume_icon),
                            g_object_unref);
 }
@@ -1075,11 +1068,11 @@ xfdesktop_volume_icon_new(GVolume *volume,
 {
     XfdesktopVolumeIcon *volume_icon;
     GMount *mount;
-    
+
     g_return_val_if_fail(G_IS_VOLUME(volume), NULL);
-    
+
     volume_icon = g_object_new(XFDESKTOP_TYPE_VOLUME_ICON, NULL);
-    volume_icon->priv->volume = g_object_ref(G_OBJECT(volume));
+    volume_icon->priv->volume = G_VOLUME(g_object_ref(G_OBJECT(volume)));
     volume_icon->priv->gscreen = screen;
 
     mount = g_volume_get_mount(volume);
@@ -1100,10 +1093,10 @@ xfdesktop_volume_icon_new(GVolume *volume,
                              G_CALLBACK(xfdesktop_icon_invalidate_pixbuf),
                              volume_icon);
 
-    g_signal_connect(volume, "changed", 
-                     G_CALLBACK(xfdesktop_volume_icon_changed), 
+    g_signal_connect(volume, "changed",
+                     G_CALLBACK(xfdesktop_volume_icon_changed),
                      volume_icon);
-    
+
     return volume_icon;
 }
 
